@@ -15,6 +15,8 @@
 #'   and B (the colorChecker function gives as output such a list obtained from the last image
 #'   in the analysis).
 #' @param resampleFactor Integer for downsampling used by \code{\link{redRes}}.
+#' @param adjustCoords Adjust landmark coordinates in case they are reversed compared to pixel
+#'    coordinates (default = FALSE).
 #'
 #' @return  Calibrated image(s) ('filename_calibrated.jpg')
 #'
@@ -33,7 +35,8 @@ colorChecker <- function(IDlist,
                          patchSize = 0.6,
                          colorCheckerXY = NULL,
                          fixedModel = NULL,
-                         resampleFactor = NULL){
+                         resampleFactor = NULL,
+                         adjustCoords = FALSE){
 
   prop <- 1- patchSize
 
@@ -79,7 +82,7 @@ colorChecker <- function(IDlist,
     rB <- flip(t(rB),'y')
 
     # X-Rite colorChecker
-    if(colorCheckerType == 'X-Rite' & is.null(fixedModel)){
+    if(all(c(colorCheckerType == 'X-Rite', is.null(fixedModel)))){
       if(is.null(colorCheckerXY)){
         print("Click on the outer corners of the X-Rite ColorChecker (1: ~brown, 2: ~cyan, 3: ~black, 4: ~white)")
 
@@ -90,7 +93,7 @@ colorChecker <- function(IDlist,
           xy <- locator(n=4)
         }
 
-        if(fixedCorners == TRUE & n ==1 ){
+        if(all(c(fixedCorners == TRUE, n ==1))){
           xy <- locator(n=4)
         }
       }
@@ -100,6 +103,22 @@ colorChecker <- function(IDlist,
         xy$x <- colorCheckerXY[[n]][,1]
         xy$y <- colorCheckerXY[[n]][,2]
 
+        # # print(xy)
+        # if(adjustCoords){
+        #
+        #   if(is.null(prepath)){
+        #     suppressWarnings(imageForExtent <- raster::stack(paste(IDlist[n], extension, sep='')))
+        #     crs(imageForExtent) <- sp::CRS('+init=EPSG:4326')
+        #   }
+        #   else{
+        #     suppressWarnings(imageForExtent <- raster::stack(paste(prepath,'/',IDlist[n], extension, sep='')))
+        #     crs(imageForExtent) <- sp::CRS('+init=EPSG:4326')
+        #   }
+        #   extPicture <- raster::extent(imageForExtent)
+        #   xy$y <- (extPicture[4]-xy$y)
+        # }
+        # # print(xy)
+
       }
 
 
@@ -108,6 +127,10 @@ colorChecker <- function(IDlist,
       if(is.null(colorCheckerXY)){
         polygon(xy$x, xy$y, border = "green")
       }
+      else{
+        plot(imRed, xlim = c(0, width(imRed)))
+        polygon(xy$x, xy$y, border = "green")
+      }
 
       xyDF <- as.data.frame(xy)
 
@@ -191,7 +214,7 @@ colorChecker <- function(IDlist,
       xySubDF_4Ba <- as.data.frame(xySubBa)
       xySubDF_4Bb <- as.data.frame(xySubBb)
 
-      if(is.null(colorCheckerXY)){
+      # if(is.null(colorCheckerXY)){
         points(xySubDF_1A, pch=20, col = 'green')
         points(xySubDF_1Ba, pch=20, col = 'red')
         points(xySubDF_1Bb, pch=20, col = 'red')
@@ -207,7 +230,7 @@ colorChecker <- function(IDlist,
         points(xySubDF_4A, pch=20, col = 'green')
         points(xySubDF_4Ba, pch=20, col = 'red')
         points(xySubDF_4Bb, pch=20, col = 'red')
-      }
+      # }
 
       labels <- list(c(1,7,13,19),
                      c(2,8,14,20),
@@ -293,10 +316,10 @@ colorChecker <- function(IDlist,
       for(e in 1:nrow(xyTot)){
 
         print(paste('Calculating observed RGB values for patch', e, sep = ' '))
-        if(is.null(colorCheckerXY)){
+        # if(is.null(colorCheckerXY)){
           polygon(c(xyTot$x1[e],xyTot$x2[e],xyTot$x4[e],xyTot$x3[e]),
                   c(xyTot$y1[e],xyTot$y2[e],xyTot$y4[e],xyTot$y3[e]), border = 'red')
-        }
+        # }
 
         outline <- rbind(c(xyTot$x1[e],xyTot$y1[e]),
                          c(xyTot$x2[e],xyTot$y2[e]),
@@ -392,7 +415,7 @@ colorChecker <- function(IDlist,
 
       imCal <- imager::as.cimg(imCal)
 
-      if(is.null(colorCheckerXY)){
+      # if(is.null(colorCheckerXY)){
         layout(matrix(c(1,2), 2, 1, byrow = TRUE))
 
           plot(imRed)
@@ -401,15 +424,15 @@ colorChecker <- function(IDlist,
 
 
 
-        if(fixedCorners == FALSE & is.null(fixedModel)){
+        if(all(c(fixedCorners == FALSE, is.null(fixedModel)))){
           todo <- readline(prompt="Press [enter] to continue and save image >>> ")
         }
-      }
+      # }
     }
 
 
     # ColorGauge Micro Analyzer colorChecker
-    if(colorCheckerType == 'ColorGauge Micro Analyzer' & is.null(fixedModel)){
+    if(all(c(colorCheckerType == 'ColorGauge Micro Analyzer', is.null(fixedModel)))){
 
       if(is.null(colorCheckerXY)){
         print("Click on the outer corners of the ColorGauge Micro Analyzer ColorChecker (1: ~brown, 2: ~cyan, 3: ~purple, 4: ~red)")
@@ -421,7 +444,7 @@ colorChecker <- function(IDlist,
           xy <- locator(n=4)
         }
 
-        if(fixedCorners == TRUE & n ==1){
+        if(all(c(fixedCorners == TRUE & n ==1))){
           xy <- locator(n=4)
         }
       }
@@ -752,7 +775,7 @@ colorChecker <- function(IDlist,
         plot(imCal)
 
 
-        if(fixedCorners == FALSE & is.null(fixedModel)){
+        if(all(c(fixedCorners == FALSE, is.null(fixedModel)))){
           todo <- readline(prompt="Press [enter] to continue and save image >>> ")
         }
       }
